==> haskell-commonmark-0.2.4.1-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark
version:              0.2.4.1
visibility:           public
id:                   commonmark-0.2.4.1-4rKljUoDDcl60Y7suHMYSv
key:                  commonmark-0.2.4.1-4rKljUoDDcl60Y7suHMYSv
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides the core data types and functions
    for parsing commonmark (<https://spec.commonmark.org>).
    The parser is fully commonmark-compliant and passes the test
    suite.  It is designed to be customizable and easily extensible.
    To customize the output, create an AST, or support a new output
    format, one need only define some new typeclass instances.
    It is also easy to add new syntax elements or modify existing ones.

    Accurate information about source positions is available
    for all block and inline elements.  Thus the library can be
    used to create an accurate syntax highlighter or
    an editor with live preview.

    The parser has been designed for robust performance
    even in pathological cases that tend to cause stack overflows or
    exponential slowdowns in other parsers, with parsing speed that
    varies linearly with input length.

    Related packages:

    - commonmark-extensions (which defines a number of syntax extensions)
    - commonmark-pandoc (which allows using this parser to create a Pandoc
    structure)
    - commonmark-cli (a command-line tool for converting and
    syntax-highlighting commonmark documents)

category:             Text
abi:                  9fa2c9925baad28d3d75bd978e0f5d2d
exposed:              True
exposed-modules:
    Commonmark Commonmark.Blocks Commonmark.Entity Commonmark.Html
    Commonmark.Inlines Commonmark.Parser Commonmark.ReferenceMap
    Commonmark.SourceMap Commonmark.Syntax Commonmark.Tag
    Commonmark.TokParsers Commonmark.Tokens Commonmark.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/commonmark-0.2.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/commonmark-0.2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark
hs-libraries:         HScommonmark-0.2.4.1-4rKljUoDDcl60Y7suHMYSv
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    parsec-3.1.15.0 text-1.2.5.0 transformers-0.5.6.2
    unicode-data-0.4.0.1-62S8hJYFsbGFRY6ebWBXf3
    unicode-transforms-0.4.0.1-Hg0olpV6WBqIwY9coUMkqW

haddock-interfaces:   /usr/share/doc/haskell-commonmark/html/commonmark.haddock
haddock-html:         /usr/share/doc/haskell-commonmark/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-0.2.4-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark
version:              0.2.4
visibility:           public
id:                   commonmark-0.2.4-JJlY2WYBAWo8kCQyjzvAP0
key:                  commonmark-0.2.4-JJlY2WYBAWo8kCQyjzvAP0
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides the core data types and functions
    for parsing commonmark (<https://spec.commonmark.org>).
    The parser is fully commonmark-compliant and passes the test
    suite.  It is designed to be customizable and easily extensible.
    To customize the output, create an AST, or support a new output
    format, one need only define some new typeclass instances.
    It is also easy to add new syntax elements or modify existing ones.

    Accurate information about source positions is available
    for all block and inline elements.  Thus the library can be
    used to create an accurate syntax highlighter or
    an editor with live preview.

    The parser has been designed for robust performance
    even in pathological cases that tend to cause stack overflows or
    exponential slowdowns in other parsers, with parsing speed that
    varies linearly with input length.

    Related packages:

    - commonmark-extensions (which defines a number of syntax extensions)
    - commonmark-pandoc (which allows using this parser to create a Pandoc
    structure)
    - commonmark-cli (a command-line tool for converting and
    syntax-highlighting commonmark documents)

category:             Text
abi:                  89c62c5b30242990d4e728240694c75b
exposed:              True
exposed-modules:
    Commonmark Commonmark.Blocks Commonmark.Entity Commonmark.Html
    Commonmark.Inlines Commonmark.Parser Commonmark.ReferenceMap
    Commonmark.SourceMap Commonmark.Syntax Commonmark.Tag
    Commonmark.TokParsers Commonmark.Tokens Commonmark.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/commonmark-0.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/commonmark-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark
hs-libraries:         HScommonmark-0.2.4-JJlY2WYBAWo8kCQyjzvAP0
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    parsec-3.1.15.0 text-1.2.5.0 transformers-0.5.6.2
    unicode-data-0.4.0.1-8z4K4wJd2V33z2O4QNIVnp
    unicode-transforms-0.4.0.1-6g51aJIPim67oyR7gC4Vbt

haddock-interfaces:   /usr/share/doc/haskell-commonmark/html/commonmark.haddock
haddock-html:         /usr/share/doc/haskell-commonmark/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
